==> matplotlib_polyroi-0.1.7.tar.gz: matplotlib_polyroi-0.1.7/README.md <==
# matplotlib-polyroi

[![CC BY 4.0][cc-by-shield]][cc-by]
[![PyPi version](https://badgen.net/pypi/v/matplotlib-polyroi/)](https://pypi.org/project/matplotlib-polyroi)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/tsmbland/matplotlib-polyroi/HEAD?filepath=%2Fscripts/Demonstration.ipynb)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Documentation Status](https://readthedocs.org/projects/matplotlib-polyroi/badge/?version=latest)](https://matplotlib-polyroi.readthedocs.io/en/latest/?badge=latest)

Module for selecting polygonal ROIs on images, spline fitting and ROI expansion

## Instructions

As a first step, I would recommend checking out the [tutorial notebook](https://nbviewer.org/github/tsmblad/matplotlib-polyroi/blob/master/scripts/Demonstration.ipynb). This can be run in the cloud using Binder (please note that it may take several minutes to open the notebook):

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/tsmbland/matplotlib-polyroi/HEAD?filepath=%2Fscripts/Demonstration.ipynb)

To run locally, download the code and install the relevant requirements (requirements.txt) in a virtual environment.

## Installation

To explore further and incorporate into your own analysis pipelines, you can install the package from PyPI using pip:

    pip install matplotlib-polyroi

If you want to make changes to the code you can download/clone this folder, navigate to it, and run:

    pip install -e .[dev]

## License

This work is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].

[![CC BY 4.0][cc-by-image]][cc-by]

[cc-by]: http://creativecommons.org/licenses/by/4.0/
[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png
[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg

==> matplotlib_polyroi-0.1.8.tar.gz: matplotlib_polyroi-0.1.8/README.md <==
# matplotlib-polyroi

[![CC BY 4.0][cc-by-shield]][cc-by]
[![PyPi version](https://badgen.net/pypi/v/matplotlib-polyroi/)](https://pypi.org/project/matplotlib-polyroi)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/tsmbland/matplotlib-polyroi/HEAD?filepath=%2Fscripts/Demonstration.ipynb)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Documentation Status](https://readthedocs.org/projects/matplotlib-polyroi/badge/?version=latest)](https://matplotlib-polyroi.readthedocs.io/en/latest/?badge=latest)

Module for selecting polygonal ROIs on images, spline fitting and ROI expansion

## Instructions

As a first step, I would recommend checking out the [tutorial notebook](https://nbviewer.org/github/tsmbland/matplotlib-polyroi/blob/master/scripts/Demonstration.ipynb). This can be run in the cloud using Binder (please note that it may take several minutes to open the notebook):

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/tsmbland/matplotlib-polyroi/HEAD?filepath=%2Fscripts/Demonstration.ipynb)

To run locally, download the code and install the relevant requirements (requirements.txt) in a virtual environment.

## Installation

To explore further and incorporate into your own analysis pipelines, you can install the package from PyPI using pip:

    pip install matplotlib-polyroi

If you want to make changes to the code you can download/clone this folder, navigate to it, and run:

    pip install -e .[dev]

## License

This work is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].

[![CC BY 4.0][cc-by-image]][cc-by]

[cc-by]: http://creativecommons.org/licenses/by/4.0/
[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png
[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg
